# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc/tradeapi/v1/orders/orders_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'grpc/tradeapi/v1/orders/orders_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import decimal_pb2 as google_dot_type_dot_decimal__pb2
from ziplime.data.data_sources.grpc.grpc_stubs.grpc.tradeapi.v1 import side_pb2 as grpc_dot_tradeapi_dot_v1_dot_side__pb2
from ziplime.data.data_sources.grpc.grpc_stubs.grpc.tradeapi.v1 import trade_pb2 as grpc_dot_tradeapi_dot_v1_dot_trade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,grpc/tradeapi/v1/orders/orders_service.proto\x12\x17grpc.tradeapi.v1.orders\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/type/decimal.proto\x1a\x1bgrpc/tradeapi/v1/side.proto\x1a\x1cgrpc/tradeapi/v1/trade.proto\"\xb5\x02\n\x11OrderTradeRequest\x12\x41\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x31.grpc.tradeapi.v1.orders.OrderTradeRequest.Action\x12\x46\n\tdata_type\x18\x02 \x01(\x0e\x32\x33.grpc.tradeapi.v1.orders.OrderTradeRequest.DataType\x12\x12\n\naccount_id\x18\x03 \x01(\t\"6\n\x06\x41\x63tion\x12\x14\n\x10\x41\x43TION_SUBSCRIBE\x10\x00\x12\x16\n\x12\x41\x43TION_UNSUBSCRIBE\x10\x01\"I\n\x08\x44\x61taType\x12\x11\n\rDATA_TYPE_ALL\x10\x00\x12\x14\n\x10\x44\x41TA_TYPE_ORDERS\x10\x01\x12\x14\n\x10\x44\x41TA_TYPE_TRADES\x10\x02\"y\n\x12OrderTradeResponse\x12\x33\n\x06orders\x18\x01 \x03(\x0b\x32#.grpc.tradeapi.v1.orders.OrderState\x12.\n\x06trades\x18\x02 \x03(\x0b\x32\x1e.grpc.tradeapi.v1.AccountTrade\"7\n\x0fGetOrderRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t\"\xfe\x03\n\x05Order\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12&\n\x08quantity\x18\x03 \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x04side\x18\x04 \x01(\x0e\x32\x16.grpc.tradeapi.v1.Side\x12\x30\n\x04type\x18\x05 \x01(\x0e\x32\".grpc.tradeapi.v1.orders.OrderType\x12;\n\rtime_in_force\x18\x06 \x01(\x0e\x32$.grpc.tradeapi.v1.orders.TimeInForce\x12)\n\x0blimit_price\x18\x07 \x01(\x0b\x32\x14.google.type.Decimal\x12(\n\nstop_price\x18\x08 \x01(\x0b\x32\x14.google.type.Decimal\x12>\n\x0estop_condition\x18\t \x01(\x0e\x32&.grpc.tradeapi.v1.orders.StopCondition\x12*\n\x04legs\x18\n \x03(\x0b\x32\x1c.grpc.tradeapi.v1.orders.Leg\x12\x17\n\x0f\x63lient_order_id\x18\x0b \x01(\t\x12:\n\x0cvalid_before\x18\x0c \x01(\x0e\x32$.grpc.tradeapi.v1.orders.ValidBefore\"c\n\x03Leg\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12&\n\x08quantity\x18\x02 \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x04side\x18\x03 \x01(\x0e\x32\x16.grpc.tradeapi.v1.Side\"\xa5\x02\n\nOrderState\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65xec_id\x18\x02 \x01(\t\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32$.grpc.tradeapi.v1.orders.OrderStatus\x12-\n\x05order\x18\x04 \x01(\x0b\x32\x1e.grpc.tradeapi.v1.orders.Order\x12/\n\x0btransact_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\taccept_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bwithdraw_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\rOrdersRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\"E\n\x0eOrdersResponse\x12\x33\n\x06orders\x18\x01 \x03(\x0b\x32#.grpc.tradeapi.v1.orders.OrderState\":\n\x12\x43\x61ncelOrderRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t*\x9e\x01\n\tOrderType\x12\x1a\n\x16ORDER_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11ORDER_TYPE_MARKET\x10\x01\x12\x14\n\x10ORDER_TYPE_LIMIT\x10\x02\x12\x13\n\x0fORDER_TYPE_STOP\x10\x03\x12\x19\n\x15ORDER_TYPE_STOP_LIMIT\x10\x04\x12\x18\n\x14ORDER_TYPE_MULTI_LEG\x10\x05*\x89\x02\n\x0bTimeInForce\x12\x1d\n\x19TIME_IN_FORCE_UNSPECIFIED\x10\x00\x12\x15\n\x11TIME_IN_FORCE_DAY\x10\x01\x12\"\n\x1eTIME_IN_FORCE_GOOD_TILL_CANCEL\x10\x02\x12$\n TIME_IN_FORCE_GOOD_TILL_CROSSING\x10\x03\x12\x15\n\x11TIME_IN_FORCE_EXT\x10\x04\x12\x19\n\x15TIME_IN_FORCE_ON_OPEN\x10\x05\x12\x1a\n\x16TIME_IN_FORCE_ON_CLOSE\x10\x06\x12\x15\n\x11TIME_IN_FORCE_IOC\x10\x07\x12\x15\n\x11TIME_IN_FORCE_FOK\x10\x08*i\n\rStopCondition\x12\x1e\n\x1aSTOP_CONDITION_UNSPECIFIED\x10\x00\x12\x1a\n\x16STOP_CONDITION_LAST_UP\x10\x01\x12\x1c\n\x18STOP_CONDITION_LAST_DOWN\x10\x02*\xe7\x06\n\x0bOrderStatus\x12\x1c\n\x18ORDER_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10ORDER_STATUS_NEW\x10\x01\x12!\n\x1dORDER_STATUS_PARTIALLY_FILLED\x10\x02\x12\x17\n\x13ORDER_STATUS_FILLED\x10\x03\x12\x1d\n\x19ORDER_STATUS_DONE_FOR_DAY\x10\x04\x12\x19\n\x15ORDER_STATUS_CANCELED\x10\x05\x12\x19\n\x15ORDER_STATUS_REPLACED\x10\x06\x12\x1f\n\x1bORDER_STATUS_PENDING_CANCEL\x10\x07\x12\x19\n\x15ORDER_STATUS_REJECTED\x10\t\x12\x1a\n\x16ORDER_STATUS_SUSPENDED\x10\n\x12\x1c\n\x18ORDER_STATUS_PENDING_NEW\x10\x0b\x12\x18\n\x14ORDER_STATUS_EXPIRED\x10\r\x12\x17\n\x13ORDER_STATUS_FAILED\x10\x10\x12\x1b\n\x17ORDER_STATUS_FORWARDING\x10\x11\x12\x15\n\x11ORDER_STATUS_WAIT\x10\x12\x12!\n\x1dORDER_STATUS_DENIED_BY_BROKER\x10\x13\x12%\n!ORDER_STATUS_REJECTED_BY_EXCHANGE\x10\x14\x12\x19\n\x15ORDER_STATUS_WATCHING\x10\x15\x12\x19\n\x15ORDER_STATUS_EXECUTED\x10\x16\x12\x19\n\x15ORDER_STATUS_DISABLED\x10\x17\x12\x1a\n\x16ORDER_STATUS_LINK_WAIT\x10\x18\x12\x1e\n\x1aORDER_STATUS_SL_GUARD_TIME\x10\x1b\x12\x1c\n\x18ORDER_STATUS_SL_EXECUTED\x10\x1c\x12\x1e\n\x1aORDER_STATUS_SL_FORWARDING\x10\x1d\x12\x1e\n\x1aORDER_STATUS_TP_GUARD_TIME\x10\x1e\x12\x1c\n\x18ORDER_STATUS_TP_EXECUTED\x10\x1f\x12\x1e\n\x1aORDER_STATUS_TP_CORRECTION\x10 \x12\x1e\n\x1aORDER_STATUS_TP_FORWARDING\x10!\x12#\n\x1fORDER_STATUS_TP_CORR_GUARD_TIME\x10\"*\x8c\x01\n\x0bValidBefore\x12\x1c\n\x18VALID_BEFORE_UNSPECIFIED\x10\x00\x12\x1b\n\x17VALID_BEFORE_END_OF_DAY\x10\x01\x12!\n\x1dVALID_BEFORE_GOOD_TILL_CANCEL\x10\x02\x12\x1f\n\x1bVALID_BEFORE_GOOD_TILL_DATE\x10\x03\x32\xb4\x05\n\rOrdersService\x12~\n\nPlaceOrder\x12\x1e.grpc.tradeapi.v1.orders.Order\x1a#.grpc.tradeapi.v1.orders.OrderState\"+\x82\xd3\xe4\x93\x02%\" /v1/accounts/{account_id}/orders:\x01*\x12\x94\x01\n\x0b\x43\x61ncelOrder\x12+.grpc.tradeapi.v1.orders.CancelOrderRequest\x1a#.grpc.tradeapi.v1.orders.OrderState\"3\x82\xd3\xe4\x93\x02-*+/v1/accounts/{account_id}/orders/{order_id}\x12\x86\x01\n\tGetOrders\x12&.grpc.tradeapi.v1.orders.OrdersRequest\x1a\'.grpc.tradeapi.v1.orders.OrdersResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/accounts/{account_id}/orders\x12\x8e\x01\n\x08GetOrder\x12(.grpc.tradeapi.v1.orders.GetOrderRequest\x1a#.grpc.tradeapi.v1.orders.OrderState\"3\x82\xd3\xe4\x93\x02-\x12+/v1/accounts/{account_id}/orders/{order_id}\x12r\n\x13SubscribeOrderTrade\x12*.grpc.tradeapi.v1.orders.OrderTradeRequest\x1a+.grpc.tradeapi.v1.orders.OrderTradeResponse(\x01\x30\x01\x42&P\x01Z\"trade_api/v1/orders/orders_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc.tradeapi.v1.orders.orders_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001Z\"trade_api/v1/orders/orders_service'
  _globals['_ORDERSSERVICE'].methods_by_name['PlaceOrder']._loaded_options = None
  _globals['_ORDERSSERVICE'].methods_by_name['PlaceOrder']._serialized_options = b'\202\323\344\223\002%\" /v1/accounts/{account_id}/orders:\001*'
  _globals['_ORDERSSERVICE'].methods_by_name['CancelOrder']._loaded_options = None
  _globals['_ORDERSSERVICE'].methods_by_name['CancelOrder']._serialized_options = b'\202\323\344\223\002-*+/v1/accounts/{account_id}/orders/{order_id}'
  _globals['_ORDERSSERVICE'].methods_by_name['GetOrders']._loaded_options = None
  _globals['_ORDERSSERVICE'].methods_by_name['GetOrders']._serialized_options = b'\202\323\344\223\002\"\022 /v1/accounts/{account_id}/orders'
  _globals['_ORDERSSERVICE'].methods_by_name['GetOrder']._loaded_options = None
  _globals['_ORDERSSERVICE'].methods_by_name['GetOrder']._serialized_options = b'\202\323\344\223\002-\022+/v1/accounts/{account_id}/orders/{order_id}'
  _globals['_ORDERTYPE']._serialized_start=1793
  _globals['_ORDERTYPE']._serialized_end=1951
  _globals['_TIMEINFORCE']._serialized_start=1954
  _globals['_TIMEINFORCE']._serialized_end=2219
  _globals['_STOPCONDITION']._serialized_start=2221
  _globals['_STOPCONDITION']._serialized_end=2326
  _globals['_ORDERSTATUS']._serialized_start=2329
  _globals['_ORDERSTATUS']._serialized_end=3200
  _globals['_VALIDBEFORE']._serialized_start=3203
  _globals['_VALIDBEFORE']._serialized_end=3343
  _globals['_ORDERTRADEREQUEST']._serialized_start=223
  _globals['_ORDERTRADEREQUEST']._serialized_end=532
  _globals['_ORDERTRADEREQUEST_ACTION']._serialized_start=403
  _globals['_ORDERTRADEREQUEST_ACTION']._serialized_end=457
  _globals['_ORDERTRADEREQUEST_DATATYPE']._serialized_start=459
  _globals['_ORDERTRADEREQUEST_DATATYPE']._serialized_end=532
  _globals['_ORDERTRADERESPONSE']._serialized_start=534
  _globals['_ORDERTRADERESPONSE']._serialized_end=655
  _globals['_GETORDERREQUEST']._serialized_start=657
  _globals['_GETORDERREQUEST']._serialized_end=712
  _globals['_ORDER']._serialized_start=715
  _globals['_ORDER']._serialized_end=1225
  _globals['_LEG']._serialized_start=1227
  _globals['_LEG']._serialized_end=1326
  _globals['_ORDERSTATE']._serialized_start=1329
  _globals['_ORDERSTATE']._serialized_end=1622
  _globals['_ORDERSREQUEST']._serialized_start=1624
  _globals['_ORDERSREQUEST']._serialized_end=1659
  _globals['_ORDERSRESPONSE']._serialized_start=1661
  _globals['_ORDERSRESPONSE']._serialized_end=1730
  _globals['_CANCELORDERREQUEST']._serialized_start=1732
  _globals['_CANCELORDERREQUEST']._serialized_end=1790
  _globals['_ORDERSSERVICE']._serialized_start=3346
  _globals['_ORDERSSERVICE']._serialized_end=4038
# @@protoc_insertion_point(module_scope)
