# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc/tradeapi/v1/marketdata/marketdata_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'grpc/tradeapi/v1/marketdata/marketdata_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import decimal_pb2 as google_dot_type_dot_decimal__pb2
from google.type import interval_pb2 as google_dot_type_dot_interval__pb2
from ziplime.data.data_sources.grpc.grpc_stubs.grpc.tradeapi.v1 import side_pb2 as grpc_dot_tradeapi_dot_v1_dot_side__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4grpc/tradeapi/v1/marketdata/marketdata_service.proto\x12\x1bgrpc.tradeapi.v1.marketdata\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/type/decimal.proto\x1a\x1agoogle/type/interval.proto\x1a\x1bgrpc/tradeapi/v1/side.proto\"\x81\x01\n\x0b\x42\x61rsRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\ttimeframe\x18\x02 \x01(\x0e\x32&.grpc.tradeapi.v1.marketdata.TimeFrame\x12\'\n\x08interval\x18\x03 \x01(\x0b\x32\x15.google.type.Interval\"N\n\x0c\x42\x61rsResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12.\n\x04\x62\x61rs\x18\x02 \x03(\x0b\x32 .grpc.tradeapi.v1.marketdata.Bar\"\x1e\n\x0cQuoteRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"R\n\rQuoteResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x31\n\x05quote\x18\x02 \x01(\x0b\x32\".grpc.tradeapi.v1.marketdata.Quote\"\"\n\x10OrderBookRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"^\n\x11OrderBookResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\torderbook\x18\x02 \x01(\x0b\x32&.grpc.tradeapi.v1.marketdata.OrderBook\"%\n\x13LatestTradesRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"Z\n\x14LatestTradesResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x32\n\x06trades\x18\x02 \x03(\x0b\x32\".grpc.tradeapi.v1.marketdata.Trade\"(\n\x15SubscribeQuoteRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\"\x84\x01\n\x16SubscribeQuoteResponse\x12\x31\n\x05quote\x18\x01 \x03(\x0b\x32\".grpc.tradeapi.v1.marketdata.Quote\x12\x37\n\x05\x65rror\x18\x02 \x01(\x0b\x32(.grpc.tradeapi.v1.marketdata.StreamError\"+\n\x19SubscribeOrderBookRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"^\n\x1aSubscribeOrderBookResponse\x12@\n\norder_book\x18\x01 \x03(\x0b\x32,.grpc.tradeapi.v1.marketdata.StreamOrderBook\"a\n\x14SubscribeBarsRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x39\n\ttimeframe\x18\x02 \x01(\x0e\x32&.grpc.tradeapi.v1.marketdata.TimeFrame\"W\n\x15SubscribeBarsResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12.\n\x04\x62\x61rs\x18\x02 \x03(\x0b\x32 .grpc.tradeapi.v1.marketdata.Bar\"\xea\x01\n\x03\x42\x61r\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x04open\x18\x02 \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04high\x18\x03 \x01(\x0b\x32\x14.google.type.Decimal\x12!\n\x03low\x18\x04 \x01(\x0b\x32\x14.google.type.Decimal\x12#\n\x05\x63lose\x18\x05 \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x06volume\x18\x06 \x01(\x0b\x32\x14.google.type.Decimal\"\xc8\x07\n\x05Quote\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x03\x61sk\x18\x03 \x01(\x0b\x32\x14.google.type.Decimal\x12&\n\x08\x61sk_size\x18\x04 \x01(\x0b\x32\x14.google.type.Decimal\x12!\n\x03\x62id\x18\x05 \x01(\x0b\x32\x14.google.type.Decimal\x12&\n\x08\x62id_size\x18\x06 \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04last\x18\x07 \x01(\x0b\x32\x14.google.type.Decimal\x12\'\n\tlast_size\x18\x08 \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x06volume\x18\t \x01(\x0b\x32\x14.google.type.Decimal\x12&\n\x08turnover\x18\n \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04open\x18\x0b \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04high\x18\x0c \x01(\x0b\x32\x14.google.type.Decimal\x12!\n\x03low\x18\r \x01(\x0b\x32\x14.google.type.Decimal\x12#\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x06\x63hange\x18\x0f \x01(\x0b\x32\x14.google.type.Decimal\x12;\n\x06option\x18\x32 \x01(\x0b\x32).grpc.tradeapi.v1.marketdata.Quote.OptionH\x00\x1a\xce\x02\n\x06Option\x12+\n\ropen_interest\x18\x01 \x01(\x0b\x32\x14.google.type.Decimal\x12\x30\n\x12implied_volatility\x18\x02 \x01(\x0b\x32\x14.google.type.Decimal\x12/\n\x11theoretical_price\x18\x03 \x01(\x0b\x32\x14.google.type.Decimal\x12#\n\x05\x64\x65lta\x18\x04 \x01(\x0b\x32\x14.google.type.Decimal\x12#\n\x05gamma\x18\x05 \x01(\x0b\x32\x14.google.type.Decimal\x12#\n\x05theta\x18\x06 \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04vega\x18\x07 \x01(\x0b\x32\x14.google.type.Decimal\x12!\n\x03rho\x18\x08 \x01(\x0b\x32\x14.google.type.DecimalB\x0b\n\tadditions\"\xa7\x03\n\tOrderBook\x12\x38\n\x04rows\x18\x01 \x03(\x0b\x32*.grpc.tradeapi.v1.marketdata.OrderBook.Row\x1a\xdf\x02\n\x03Row\x12#\n\x05price\x18\x01 \x01(\x0b\x32\x14.google.type.Decimal\x12)\n\tsell_size\x18\x02 \x01(\x0b\x32\x14.google.type.DecimalH\x00\x12(\n\x08\x62uy_size\x18\x03 \x01(\x0b\x32\x14.google.type.DecimalH\x00\x12\x41\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32\x31.grpc.tradeapi.v1.marketdata.OrderBook.Row.Action\x12\x0c\n\x04mpid\x18\x05 \x01(\t\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x11\n\rACTION_REMOVE\x10\x01\x12\x0e\n\nACTION_ADD\x10\x02\x12\x11\n\rACTION_UPDATE\x10\x03\x42\x06\n\x04side\"\xc5\x01\n\x05Trade\x12\x10\n\x08trade_id\x18\x01 \x01(\t\x12\x0c\n\x04mpid\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x05price\x18\x04 \x01(\x0b\x32\x14.google.type.Decimal\x12\"\n\x04size\x18\x05 \x01(\x0b\x32\x14.google.type.Decimal\x12$\n\x04side\x18\x06 \x01(\x0e\x32\x16.grpc.tradeapi.v1.Side\"0\n\x0bStreamError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xc9\x03\n\x0fStreamOrderBook\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12>\n\x04rows\x18\x02 \x03(\x0b\x32\x30.grpc.tradeapi.v1.marketdata.StreamOrderBook.Row\x1a\xe5\x02\n\x03Row\x12#\n\x05price\x18\x01 \x01(\x0b\x32\x14.google.type.Decimal\x12)\n\tsell_size\x18\x02 \x01(\x0b\x32\x14.google.type.DecimalH\x00\x12(\n\x08\x62uy_size\x18\x03 \x01(\x0b\x32\x14.google.type.DecimalH\x00\x12G\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32\x37.grpc.tradeapi.v1.marketdata.StreamOrderBook.Row.Action\x12\x0c\n\x04mpid\x18\x05 \x01(\t\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x11\n\rACTION_REMOVE\x10\x01\x12\x0e\n\nACTION_ADD\x10\x02\x12\x11\n\rACTION_UPDATE\x10\x03\x42\x06\n\x04side\".\n\x1cSubscribeLatestTradesRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\"c\n\x1dSubscribeLatestTradesResponse\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x32\n\x06trades\x18\x02 \x03(\x0b\x32\".grpc.tradeapi.v1.marketdata.Trade*\x8b\x02\n\tTimeFrame\x12\x1a\n\x16TIME_FRAME_UNSPECIFIED\x10\x00\x12\x11\n\rTIME_FRAME_M1\x10\x01\x12\x11\n\rTIME_FRAME_M5\x10\x05\x12\x12\n\x0eTIME_FRAME_M15\x10\t\x12\x12\n\x0eTIME_FRAME_M30\x10\x0b\x12\x11\n\rTIME_FRAME_H1\x10\x0c\x12\x11\n\rTIME_FRAME_H2\x10\r\x12\x11\n\rTIME_FRAME_H4\x10\x0f\x12\x11\n\rTIME_FRAME_H8\x10\x11\x12\x10\n\x0cTIME_FRAME_D\x10\x13\x12\x10\n\x0cTIME_FRAME_W\x10\x14\x12\x11\n\rTIME_FRAME_MN\x10\x15\x12\x11\n\rTIME_FRAME_QR\x10\x16\x32\x80\t\n\x11MarketDataService\x12\x82\x01\n\x04\x42\x61rs\x12(.grpc.tradeapi.v1.marketdata.BarsRequest\x1a).grpc.tradeapi.v1.marketdata.BarsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/instruments/{symbol}/bars\x12\x92\x01\n\tLastQuote\x12).grpc.tradeapi.v1.marketdata.QuoteRequest\x1a*.grpc.tradeapi.v1.marketdata.QuoteResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/instruments/{symbol}/quotes/latest\x12\x96\x01\n\tOrderBook\x12-.grpc.tradeapi.v1.marketdata.OrderBookRequest\x1a..grpc.tradeapi.v1.marketdata.OrderBookResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/instruments/{symbol}/orderbook\x12\xa3\x01\n\x0cLatestTrades\x12\x30.grpc.tradeapi.v1.marketdata.LatestTradesRequest\x1a\x31.grpc.tradeapi.v1.marketdata.LatestTradesResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/instruments/{symbol}/trades/latest\x12{\n\x0eSubscribeQuote\x12\x32.grpc.tradeapi.v1.marketdata.SubscribeQuoteRequest\x1a\x33.grpc.tradeapi.v1.marketdata.SubscribeQuoteResponse0\x01\x12\x87\x01\n\x12SubscribeOrderBook\x12\x36.grpc.tradeapi.v1.marketdata.SubscribeOrderBookRequest\x1a\x37.grpc.tradeapi.v1.marketdata.SubscribeOrderBookResponse0\x01\x12\x90\x01\n\x15SubscribeLatestTrades\x12\x39.grpc.tradeapi.v1.marketdata.SubscribeLatestTradesRequest\x1a:.grpc.tradeapi.v1.marketdata.SubscribeLatestTradesResponse0\x01\x12x\n\rSubscribeBars\x12\x31.grpc.tradeapi.v1.marketdata.SubscribeBarsRequest\x1a\x32.grpc.tradeapi.v1.marketdata.SubscribeBarsResponse0\x01\x42.P\x01Z*trade_api/v1/marketdata/marketdata_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc.tradeapi.v1.marketdata.marketdata_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001Z*trade_api/v1/marketdata/marketdata_service'
  _globals['_MARKETDATASERVICE'].methods_by_name['Bars']._loaded_options = None
  _globals['_MARKETDATASERVICE'].methods_by_name['Bars']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/instruments/{symbol}/bars'
  _globals['_MARKETDATASERVICE'].methods_by_name['LastQuote']._loaded_options = None
  _globals['_MARKETDATASERVICE'].methods_by_name['LastQuote']._serialized_options = b'\202\323\344\223\002(\022&/v1/instruments/{symbol}/quotes/latest'
  _globals['_MARKETDATASERVICE'].methods_by_name['OrderBook']._loaded_options = None
  _globals['_MARKETDATASERVICE'].methods_by_name['OrderBook']._serialized_options = b'\202\323\344\223\002$\022\"/v1/instruments/{symbol}/orderbook'
  _globals['_MARKETDATASERVICE'].methods_by_name['LatestTrades']._loaded_options = None
  _globals['_MARKETDATASERVICE'].methods_by_name['LatestTrades']._serialized_options = b'\202\323\344\223\002(\022&/v1/instruments/{symbol}/trades/latest'
  _globals['_TIMEFRAME']._serialized_start=3823
  _globals['_TIMEFRAME']._serialized_end=4090
  _globals['_BARSREQUEST']._serialized_start=233
  _globals['_BARSREQUEST']._serialized_end=362
  _globals['_BARSRESPONSE']._serialized_start=364
  _globals['_BARSRESPONSE']._serialized_end=442
  _globals['_QUOTEREQUEST']._serialized_start=444
  _globals['_QUOTEREQUEST']._serialized_end=474
  _globals['_QUOTERESPONSE']._serialized_start=476
  _globals['_QUOTERESPONSE']._serialized_end=558
  _globals['_ORDERBOOKREQUEST']._serialized_start=560
  _globals['_ORDERBOOKREQUEST']._serialized_end=594
  _globals['_ORDERBOOKRESPONSE']._serialized_start=596
  _globals['_ORDERBOOKRESPONSE']._serialized_end=690
  _globals['_LATESTTRADESREQUEST']._serialized_start=692
  _globals['_LATESTTRADESREQUEST']._serialized_end=729
  _globals['_LATESTTRADESRESPONSE']._serialized_start=731
  _globals['_LATESTTRADESRESPONSE']._serialized_end=821
  _globals['_SUBSCRIBEQUOTEREQUEST']._serialized_start=823
  _globals['_SUBSCRIBEQUOTEREQUEST']._serialized_end=863
  _globals['_SUBSCRIBEQUOTERESPONSE']._serialized_start=866
  _globals['_SUBSCRIBEQUOTERESPONSE']._serialized_end=998
  _globals['_SUBSCRIBEORDERBOOKREQUEST']._serialized_start=1000
  _globals['_SUBSCRIBEORDERBOOKREQUEST']._serialized_end=1043
  _globals['_SUBSCRIBEORDERBOOKRESPONSE']._serialized_start=1045
  _globals['_SUBSCRIBEORDERBOOKRESPONSE']._serialized_end=1139
  _globals['_SUBSCRIBEBARSREQUEST']._serialized_start=1141
  _globals['_SUBSCRIBEBARSREQUEST']._serialized_end=1238
  _globals['_SUBSCRIBEBARSRESPONSE']._serialized_start=1240
  _globals['_SUBSCRIBEBARSRESPONSE']._serialized_end=1327
  _globals['_BAR']._serialized_start=1330
  _globals['_BAR']._serialized_end=1564
  _globals['_QUOTE']._serialized_start=1567
  _globals['_QUOTE']._serialized_end=2535
  _globals['_QUOTE_OPTION']._serialized_start=2188
  _globals['_QUOTE_OPTION']._serialized_end=2522
  _globals['_ORDERBOOK']._serialized_start=2538
  _globals['_ORDERBOOK']._serialized_end=2961
  _globals['_ORDERBOOK_ROW']._serialized_start=2610
  _globals['_ORDERBOOK_ROW']._serialized_end=2961
  _globals['_ORDERBOOK_ROW_ACTION']._serialized_start=2867
  _globals['_ORDERBOOK_ROW_ACTION']._serialized_end=2953
  _globals['_TRADE']._serialized_start=2964
  _globals['_TRADE']._serialized_end=3161
  _globals['_STREAMERROR']._serialized_start=3163
  _globals['_STREAMERROR']._serialized_end=3211
  _globals['_STREAMORDERBOOK']._serialized_start=3214
  _globals['_STREAMORDERBOOK']._serialized_end=3671
  _globals['_STREAMORDERBOOK_ROW']._serialized_start=3314
  _globals['_STREAMORDERBOOK_ROW']._serialized_end=3671
  _globals['_STREAMORDERBOOK_ROW_ACTION']._serialized_start=2867
  _globals['_STREAMORDERBOOK_ROW_ACTION']._serialized_end=2953
  _globals['_SUBSCRIBELATESTTRADESREQUEST']._serialized_start=3673
  _globals['_SUBSCRIBELATESTTRADESREQUEST']._serialized_end=3719
  _globals['_SUBSCRIBELATESTTRADESRESPONSE']._serialized_start=3721
  _globals['_SUBSCRIBELATESTTRADESRESPONSE']._serialized_end=3820
  _globals['_MARKETDATASERVICE']._serialized_start=4093
  _globals['_MARKETDATASERVICE']._serialized_end=5245
# @@protoc_insertion_point(module_scope)
