# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc/tradeapi/v1/auth/auth_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'grpc/tradeapi/v1/auth/auth_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(grpc/tradeapi/v1/auth/auth_service.proto\x12\x15grpc.tradeapi.v1.auth\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1d\n\x0b\x41uthRequest\x12\x0e\n\x06secret\x18\x01 \x01(\t\"\x1d\n\x0c\x41uthResponse\x12\r\n\x05token\x18\x01 \x01(\t\"$\n\x13TokenDetailsRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\xda\x01\n\x14TokenDetailsResponse\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x0emd_permissions\x18\x03 \x03(\x0b\x32#.grpc.tradeapi.v1.auth.MDPermission\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x04 \x03(\t\x12\x10\n\x08readonly\x18\x05 \x01(\x08\"\x8d\x03\n\x0cMDPermission\x12\x43\n\x0bquote_level\x18\x01 \x01(\x0e\x32..grpc.tradeapi.v1.auth.MDPermission.QuoteLevel\x12\x15\n\rdelay_minutes\x18\x02 \x01(\x05\x12\r\n\x03mic\x18\x03 \x01(\tH\x00\x12\x11\n\x07\x63ountry\x18\x04 \x01(\tH\x00\x12\x13\n\tcontinent\x18\x05 \x01(\tH\x00\x12\x13\n\tworldwide\x18\x06 \x01(\x08H\x00\"\xc7\x01\n\nQuoteLevel\x12\x1b\n\x17QUOTE_LEVEL_UNSPECIFIED\x10\x00\x12\x1a\n\x16QUOTE_LEVEL_LAST_PRICE\x10\x01\x12\x1e\n\x1aQUOTE_LEVEL_BEST_BID_OFFER\x10\x02\x12\x1f\n\x1bQUOTE_LEVEL_DEPTH_OF_MARKET\x10\x03\x12\x1d\n\x19QUOTE_LEVEL_DEPTH_OF_BOOK\x10\x04\x12 \n\x1cQUOTE_LEVEL_ACCESS_FORBIDDEN\x10\x05\x42\x0b\n\tcondition\",\n\x1aSubscribeJwtRenewalRequest\x12\x0e\n\x06secret\x18\x01 \x01(\t\",\n\x1bSubscribeJwtRenewalResponse\x12\r\n\x05token\x18\x01 \x01(\t2\x82\x03\n\x0b\x41uthService\x12h\n\x04\x41uth\x12\".grpc.tradeapi.v1.auth.AuthRequest\x1a#.grpc.tradeapi.v1.auth.AuthResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/sessions:\x01*\x12\x88\x01\n\x0cTokenDetails\x12*.grpc.tradeapi.v1.auth.TokenDetailsRequest\x1a+.grpc.tradeapi.v1.auth.TokenDetailsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/sessions/details:\x01*\x12~\n\x13SubscribeJwtRenewal\x12\x31.grpc.tradeapi.v1.auth.SubscribeJwtRenewalRequest\x1a\x32.grpc.tradeapi.v1.auth.SubscribeJwtRenewalResponse0\x01\x42\"P\x01Z\x1etrade_api/v1/auth/auth_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc.tradeapi.v1.auth.auth_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001Z\036trade_api/v1/auth/auth_service'
  _globals['_AUTHSERVICE'].methods_by_name['Auth']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['Auth']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/sessions:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['TokenDetails']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['TokenDetails']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/sessions/details:\001*'
  _globals['_AUTHREQUEST']._serialized_start=130
  _globals['_AUTHREQUEST']._serialized_end=159
  _globals['_AUTHRESPONSE']._serialized_start=161
  _globals['_AUTHRESPONSE']._serialized_end=190
  _globals['_TOKENDETAILSREQUEST']._serialized_start=192
  _globals['_TOKENDETAILSREQUEST']._serialized_end=228
  _globals['_TOKENDETAILSRESPONSE']._serialized_start=231
  _globals['_TOKENDETAILSRESPONSE']._serialized_end=449
  _globals['_MDPERMISSION']._serialized_start=452
  _globals['_MDPERMISSION']._serialized_end=849
  _globals['_MDPERMISSION_QUOTELEVEL']._serialized_start=637
  _globals['_MDPERMISSION_QUOTELEVEL']._serialized_end=836
  _globals['_SUBSCRIBEJWTRENEWALREQUEST']._serialized_start=851
  _globals['_SUBSCRIBEJWTRENEWALREQUEST']._serialized_end=895
  _globals['_SUBSCRIBEJWTRENEWALRESPONSE']._serialized_start=897
  _globals['_SUBSCRIBEJWTRENEWALRESPONSE']._serialized_end=941
  _globals['_AUTHSERVICE']._serialized_start=944
  _globals['_AUTHSERVICE']._serialized_end=1330
# @@protoc_insertion_point(module_scope)
